@@ -608,7 +608,9 @@ def dirfdb(searchdb=None, antiblock=False, path_dir_=None, return_pathed=True):
             while editando:
                 pass
             editando = True
-        if path_dir_ != None:
+        if path_dir_ == None:
+            global path_dir
+        else:
             path_dir = path_dir_
         if searchdb != None:
             path_dir.append(searchdb)
@@ -678,7 +680,7 @@ def cdadd(path_to_update, replace_all_path=False, path_dir_=None):
                 for item_path_new in path_to_update:
                     path_dir.append(item_path_new)
         else:
-            if len(path_to_update) > 1 and '/' in path_to_update:
+            if len(str(path_to_update)) > 2 and '/' in path_to_update:
                 return cdadd(path_to_update.split('/'), True)
                 
             if replace_all_path:
@@ -704,7 +706,9 @@ def remove_infodb(path_delete=None, path_dir_=None, antiblock=False):
             while editando:
                 pass
             editando = True
-        if path_dir_ != None:
+        if path_dir_ == None:
+            global path_dir
+        else:
             path_dir = path_dir_
         if path_delete == None:
             path_delete = path_dir
@@ -781,12 +785,15 @@ def cdmin(qntd_min=1, path_dir_=None):
     if client_use:
         client.send(f'cdmin;{qntd_min}'.encode('utf-8'))
     else:
-        if path_dir_ != None:
+        if path_dir_ == None:
+            global path_dir
+        else:
             path_dir = path_dir_
         if qntd_min == 0:
             path_dir = []
         elif len(path_dir) > 0:
-            path_dir.pop(-qntd_min)
+            for c in range(0, qntd_min):
+                path_dir.pop(-1)
         return path_dir
 
 def dirfdbp():
